@@ -1,9 +1,13 @@
 package Test_Helper;
 
+my $test_version;
 BEGIN {
     $ENV{TEST_SANDBOX_HOME}="$ENV{PWD}/t/test_sb";
     $ENV{PERL5LIB}="$ENV{PWD}/lib";
     $ENV{PATH}="$ENV{PWD}/bin:$ENV{PATH}";
+    $ENV{TEST_VERSION} = $ENV{TEST_VERSION} || '5.0.77';
+    $ENV{SANDBOX_AS_ROOT} = 1;
+    $test_version = $ENV{TEST_VERSION} ;
 };
 
 use strict;
@@ -14,17 +18,16 @@ our @EXPORT_OK= qw( test_sandbox);
 our @EXPORT = @EXPORT_OK;
 
 sub test_sandbox {
-    my ($cmd, $expected_tests) = @_;
+    my ($cmd, $expected_tests, $informative) = @_;
     unless ($cmd) {
         die "command expected\n";
     }
     unless ($expected_tests) {
-        die "how many tests expected as second parameter\n";
+        die "number of tests expected as second parameter\n";
     }
     $expected_tests =~ /^\d+$/
         or die "the 'expected tests' parameter must be a number \n";
 
-    my $test_version = $ENV{TEST_VERSION} || '5.0.77';
     ##
     # accepts either a bare version 
     #   (e.g. 5.0.79)
@@ -36,13 +39,14 @@ sub test_sandbox {
     if (   ( -d $test_version) 
         or (( -f $test_version ) && ($test_version =~ /\.tar\.gz$/) )
         or ( -d "$ENV{HOME}/opt/mysql/$test_version")) {
-        warn "Testing <$test_version>. Please wait. This will take a few minutes\n";
+        warn  "Testing <$test_version>. "
+            . "Please wait. This will take a few minutes\n" if $informative;
         print "1..$expected_tests\n";
     }
     else {
         print "1..1\n";
-        print "ok 1 # skip - no binaries found for $test_version"
-               . " - See the README under 'TESTING' for more options.\n";
+        print "ok 1 # skip - no binaries found for $test_version\n";
+        print " - See the README under 'TESTING' for more options.\n" if $informative;
         exit;
     }
 
